@@ -4,7 +4,7 @@ use warnings;
 use strict;
 require DateTime::Format::Human::Duration::Locale;
 
-our $VERSION = '0.4';
+our $VERSION = '0.5';
 
 sub new {
     bless { 'locale_cache' => {} }, 'DateTime::Format::Human::Duration';  
@@ -223,7 +223,7 @@ This facilitates, for example, this L<Locale::Maketext> vernacular which becomes
 Localization is provided by the included DateTime::Format::Human::Duration::Locale modules.
 
 Included are DateTime::Format::Human::Duration::Locale::es, DateTime::Format::Human::Duration::Locale::fr, DateTime::Format::Human::Duration::Locale::pt,
-DateTime::Format::Human::Duration::Locale::de
+DateTime::Format::Human::Duration::Locale::de, DateTime::Format::Human::Duration::Locale::it
 
 More will be included as time permits/folks volunteer/CLDR becomes an option
 
